dnl======================================================================
dnl   Enable DTT compilation
dnl======================================================================

AC_DEFUN([AC_GDS_ENABLE_DTT],
[
  AC_MSG_CHECKING([whether to build dtt])
  need_dtt=no
  need_onlydtt=no
  need_dttgui=
  AC_ARG_ENABLE(dtt,
  AC_HELP_STRING( [--enable-dtt], [Build dtt]),
                  [need_dtt=${enableval}]
                  )
  AC_ARG_ENABLE( [only_dtt],
                 AC_HELP_STRING( [--enable-only-dtt], [Build dtt only]),
                 [need_onlydtt=${enableval}]
                 )
  AS_IF( [test $need_onlydtt = "yes"],
         [ need_dtt="yes"
           AC_MSG_RESULT([Only]) ],
         [ AC_MSG_RESULT([${need_dtt}])
         ] )

  need_dttgui=yes
  AC_ARG_ENABLE( [nogui],
	               AC_HELP_STRING([--enable-nogui], [Build dtt without gui]),
	               [test "x${enableval}" = "xyes" && need_dttgui="no"]
                 )

  have_epics=
  AC_ARG_WITH( [epics],
               AC_HELP_STRING( [--with-epics@<:@=DIR@:>@],
                               [epics top-level directory @<:@DTT/epics@:>@]
		                           ),
              [have_epics=yes],
              [have_epics=no]
              )

  dtt_defines=
  rpcgen_flags=
  epicslibs=
  epicscflags=
  build_epics=no
  if test $need_dtt = "yes"
  then
    echo "$as_me:$LINENO: checking for DTT GUI" >&5
    echo $ECHO_N "checking for DTT GUI... $ECHO_C"
    AS_IF( [test x$need_dttgui = "xno"],
           [ need_dttgui=no
             echo NO],
           [ need_dttgui=yes
             echo yes ]
           )

    dtt_defines="-DLIGO_GDS -D_CONFIG_DYNAMIC -D_ADVANCED_LIGO -DCOMPAT_INITIAL_LIGO=1"
    AC_CHECK_PROGS([RPCGEN],[rpcgen-mt rpcgen])
    AS_CASE( [$host],
             [*solaris*],[
               osarch=solaris
               dtt_defines="$dtt_defines -D__EXTENSIONS__"
	             AS_IF( [ test `uname -m` = "i86pc" ],
	                    [ arch=solaris-x86-gnu],
	                    [ arch=solaris-sparc] ) ],
             [*linux*],[
	             dtt_defines="$dtt_defines -DPORTMAP"
               osarch=Linux
	             AS_IF( [test `uname -m` = "x86_64"],
	                    [arch=linux-x86_64],
	                    [arch=linux-x86] ) ],
             [*darwin*],[
	             dtt_defines="$dtt_defines -DPORTMAP -DAVOID_SIGNALS"
               osarch=Darwin
	             AS_IF( [test `uname -m` = "x86_64"],
  	                  [arch=darwin-x86],
	                    [arch=darwin-x86] ) ],
	           [ dtt_defines="$dtt_defines -DPORTMAP"
               osarch=Linux
               arch=linux-x86 ]
           )

    dnl -----------------------------------------------------------------
    dnl darwin - mojove - broken
    dnl darwin - pre-mojove - $rpcgen_flags -b -M
    dnl -----------------------------------------------------------------
    rpcgen_flags="-C -N"
    AS_CASE([$host],
        [*solaris*],[rpcgen_flags="$rpcgen_flags -M"],
        [*linux*],[rpcgen_flags="$rpcgen_flags -M"],
        [*darwin*],[rpcgen_flags="broken"],
        [rpcgen_flags="$rpcgen_flags -M"]
    )

    if test "x$buildtype" = "xonline" ;
    then
      if test "x$have_epics" = "xyes" -a "x$with_epics" = "xno"
      then
        epicslibs=""
	      epicscflags=""
      elif test "x$have_epics" = "xyes" ; then
        AS_IF( [test "x$with_epics" = "xyes" -o "x$with_epics" = "x"],
               [ echo "$as_me:$LINENO: checking for epics archive for arch=$arch" >&5
	               echo $ECHO_N "checking for epics base libs DTT/epics/base/lib/${arch} ... $ECHO_C"
                 AS_IF( [test -f "DTT/epics/base/lib/${arch}/libca.a"],
            	          [ epicslibs="-L../epics/base/lib/${arch} -lca -lCom -L../epics/extensions/lib/${arch} -lezca"
                          epicscflags="-I../epics/base/include -I../epics/base/include/compiler/gcc -I../epics/base/include/os/${osarch} -I../epics/extensions/include"
	                        build_epics=yes
		                      echo "$build_epics" ],
                        [ build_epics=no
		                      echo "$build_epics"
		                      echo $ECHO_N "** REMEMBER to expand EPICS tar-ball in DTT/epics ! $ECHO_N" ]
                      ) ],
               [ epicstop="${with_epics}"
                 echo "$as_me:$LINENO: checking for epics archive for arch=$arch" >&5
	               echo $ECHO_N "checking for epics base libs ${epicstop}/base/lib/${arch} ... $ECHO_C"
                 AS_IF( [test -f "${epicstop}/base/lib/${arch}/libca.a"],
            	          [ epicslibs="-L${epicstop}/base/lib/${arch} -lca -lCom -L${epicstop}/extensions/lib/${arch} -lezca"
                          epicscflags="-I${epicstop}/base/include -I${epicstop}/base/include/compiler/gcc -I${epicstop}/base/include/os/${osarch} -I${epicstop}/extensions/include"
	                        build_epics=yes],
                        [ build_epics=no ]
                      )
	               echo "$build_epics" ] )
      fi
      AS_IF( [test "x$build_epics" = "xno"],
             [dtt_defines="$dtt_defines -DGDS_NO_EPICS"],
             [dtt_defines="$dtt_defines -DGDS_ONLINE"]
             )
    else
      dtt_defines="$dtt_defines -DGDS_NO_EPICS"
    fi
  else
    need_dttgui=no
  fi

  AM_CONDITIONAL([build_dtt], [test "x$need_dtt" = "xyes"])
  AM_CONDITIONAL([build_onlydtt], [test "x$need_onlydtt" = "xyes"])
  AM_CONDITIONAL([build_dttgui], [test "x$need_dttgui" = "xyes"])
  AM_CONDITIONAL([build_ezca], [test "x$build_epics" = "xyes"])
  AM_CONDITIONAL([rpcgen_ok], [test "$rpcgen_flags" != "broken"])
  AC_SUBST(dtt_defines)
  AC_SUBST(rpcgen_flags)
  AC_SUBST(epicslibs)
  AC_SUBST(epicscflags)

  echo $ECHO_N "checking for rts ... $ECHO_C"

  AC_ARG_ENABLE( [rts],
                 [--enable-rts  add realtime site],
                 [ AS_CASE( ["${enableval}"],
                            [llo],[rts=llo],
                            [lho],[rts=lho],
                            [mit],[rts=mit],
                            [geo],[rts=geo],
                            [ AC_MSG_ERROR([bad site ${withval} for --with-rts]) ] )
                 ],[rts=]
               )
  add_rts=false
  AM_CONDITIONAL([add_rts], [test x$rts != x])
  AM_CONDITIONAL([site_llo], [test x$rts = xllo])
  AM_CONDITIONAL([site_lho], [test x$rts = xlho])
  AM_CONDITIONAL([site_mit], [test x$rts = xmit])
  AM_CONDITIONAL([site_geo], [test x$rts = xgeo])
  echo "$rts"

  echo $ECHO_N "checking for dmtviewer enable flag... $ECHO_C"
  AC_ARG_ENABLE( [dmtviewer],
                 [--enable-dmtviewer  add dmtviewer anyway],
                 [ AS_CASE( ["${enableval}"],
                            [yes],[dmtviewer=true],
                            [no],[dmtviewer=false],
                            [ AC_MSG_ERROR([bad logic ${withval} for --with-dmtviewer]) ] )
                 ],[dmtviewer=false]
               )
  add_dmtviewer=false
  AM_CONDITIONAL([add_dmtviewer], [test x$dmtviewer = xtrue])
  echo "$dmtviewer"

  echo $ECHO_N

])
